Logarithm2

Trait Logarithm2 

pub trait Logarithm2 {
    type Output;
}
A type operator for taking the integer binary logarithm of Self.

The integer binary logarighm of n is the largest integer m such that n >= 2^m. This definition is equivalent to truncating the real-valued binary logarithm: floor(log2(n)).

Required Associated Types

type Output

The result of the integer binary logarithm.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<N> Logarithm2 for N
where N: PrivateLogarithm2,

Source

type Output = <N as PrivateLogarithm2>::Output